@@ -1,15 +1,5 @@
-# Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-#
-# Licensed under the Apache License, Version 2.0 (the "License").
-# You may not use this file except in compliance with the License.
-# A copy of the License is located at
-#
-#  http://aws.amazon.com/apache2.0
-#
-# or in the "license" file accompanying this file. This file is distributed
-# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-# express or implied. See the License for the specific language governing
-# permissions and limitations under the License.
+# Copyright Amazon.com, Inc. or its affiliates.  All rights reserved.
+# SPDX-License-Identifier: Apache-2.0.
 
 # This file is generated
 
@@ -257,11 +247,30 @@ class IotIdentityClient(awsiot.MqttServiceClient):
             payload_to_class_fn=ErrorResponse.from_payload)
 
 class CreateCertificateFromCsrRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *certificate_signing_request* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['certificate_signing_request']
 
-    def __init__(self, certificate_signing_request=None):
-        # type: (typing.Optional[str]) -> None
-        self.certificate_signing_request = certificate_signing_request # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a CreateCertificateFromCsrRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *certificate_signing_request* (``str``)
+        """
+
+        self.certificate_signing_request = kwargs.get('certificate_signing_request')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['certificate_signing_request'], args):
+            setattr(self, key, val)
 
     def to_payload(self):
         # type: () -> typing.Dict[str, typing.Any]
@@ -271,13 +280,36 @@ class CreateCertificateFromCsrRequest(awsiot.ModeledClass):
         return payload
 
 class CreateCertificateFromCsrResponse(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *certificate_id* (``str``)
+        * *certificate_ownership_token* (``str``)
+        * *certificate_pem* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['certificate_id', 'certificate_ownership_token', 'certificate_pem']
 
-    def __init__(self, certificate_id=None, certificate_ownership_token=None, certificate_pem=None):
-        # type: (typing.Optional[str], typing.Optional[str], typing.Optional[str]) -> None
-        self.certificate_id = certificate_id # type: typing.Optional[str]
-        self.certificate_ownership_token = certificate_ownership_token # type: typing.Optional[str]
-        self.certificate_pem = certificate_pem # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a CreateCertificateFromCsrResponse instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *certificate_id* (``str``)
+            * *certificate_ownership_token* (``str``)
+            * *certificate_pem* (``str``)
+        """
+
+        self.certificate_id = kwargs.get('certificate_id')
+        self.certificate_ownership_token = kwargs.get('certificate_ownership_token')
+        self.certificate_pem = kwargs.get('certificate_pem')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['certificate_id', 'certificate_ownership_token', 'certificate_pem'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -295,28 +327,83 @@ class CreateCertificateFromCsrResponse(awsiot.ModeledClass):
         return new
 
 class CreateCertificateFromCsrSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = []
 
-    def __init__(self):
-        # type: () -> None
-        pass
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a CreateCertificateFromCsrSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+        """
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip([], args):
+            setattr(self, key, val)
 
 class CreateKeysAndCertificateRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = []
 
-    def __init__(self):
-        # type: () -> None
-        pass
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a CreateKeysAndCertificateRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+        """
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip([], args):
+            setattr(self, key, val)
 
 class CreateKeysAndCertificateResponse(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *certificate_id* (``str``)
+        * *certificate_ownership_token* (``str``)
+        * *certificate_pem* (``str``)
+        * *private_key* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['certificate_id', 'certificate_ownership_token', 'certificate_pem', 'private_key']
 
-    def __init__(self, certificate_id=None, certificate_ownership_token=None, certificate_pem=None, private_key=None):
-        # type: (typing.Optional[str], typing.Optional[str], typing.Optional[str], typing.Optional[str]) -> None
-        self.certificate_id = certificate_id # type: typing.Optional[str]
-        self.certificate_ownership_token = certificate_ownership_token # type: typing.Optional[str]
-        self.certificate_pem = certificate_pem # type: typing.Optional[str]
-        self.private_key = private_key # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a CreateKeysAndCertificateResponse instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *certificate_id* (``str``)
+            * *certificate_ownership_token* (``str``)
+            * *certificate_pem* (``str``)
+            * *private_key* (``str``)
+        """
+
+        self.certificate_id = kwargs.get('certificate_id')
+        self.certificate_ownership_token = kwargs.get('certificate_ownership_token')
+        self.certificate_pem = kwargs.get('certificate_pem')
+        self.private_key = kwargs.get('private_key')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['certificate_id', 'certificate_ownership_token', 'certificate_pem', 'private_key'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -337,20 +424,58 @@ class CreateKeysAndCertificateResponse(awsiot.ModeledClass):
         return new
 
 class CreateKeysAndCertificateSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = []
 
-    def __init__(self):
-        # type: () -> None
-        pass
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a CreateKeysAndCertificateSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+        """
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip([], args):
+            setattr(self, key, val)
 
 class ErrorResponse(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *error_code* (``str``)
+        * *error_message* (``str``)
+        * *status_code* (``int``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['error_code', 'error_message', 'status_code']
 
-    def __init__(self, error_code=None, error_message=None, status_code=None):
-        # type: (typing.Optional[str], typing.Optional[str], typing.Optional[int]) -> None
-        self.error_code = error_code # type: typing.Optional[str]
-        self.error_message = error_message # type: typing.Optional[str]
-        self.status_code = status_code # type: typing.Optional[int]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a ErrorResponse instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *error_code* (``str``)
+            * *error_message* (``str``)
+            * *status_code* (``int``)
+        """
+
+        self.error_code = kwargs.get('error_code')
+        self.error_message = kwargs.get('error_message')
+        self.status_code = kwargs.get('status_code')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['error_code', 'error_message', 'status_code'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -368,13 +493,36 @@ class ErrorResponse(awsiot.ModeledClass):
         return new
 
 class RegisterThingRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *certificate_ownership_token* (``str``)
+        * *parameters* (``typing.Dict[str, str]``)
+        * *template_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['certificate_ownership_token', 'parameters', 'template_name']
 
-    def __init__(self, certificate_ownership_token=None, parameters=None, template_name=None):
-        # type: (typing.Optional[str], typing.Optional[typing.Dict[str, str]], typing.Optional[str]) -> None
-        self.certificate_ownership_token = certificate_ownership_token # type: typing.Optional[str]
-        self.parameters = parameters # type: typing.Optional[typing.Dict[str, str]]
-        self.template_name = template_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a RegisterThingRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *certificate_ownership_token* (``str``)
+            * *parameters* (``typing.Dict[str, str]``)
+            * *template_name* (``str``)
+        """
+
+        self.certificate_ownership_token = kwargs.get('certificate_ownership_token')
+        self.parameters = kwargs.get('parameters')
+        self.template_name = kwargs.get('template_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['certificate_ownership_token', 'parameters', 'template_name'], args):
+            setattr(self, key, val)
 
     def to_payload(self):
         # type: () -> typing.Dict[str, typing.Any]
@@ -386,12 +534,33 @@ class RegisterThingRequest(awsiot.ModeledClass):
         return payload
 
 class RegisterThingResponse(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *device_configuration* (``typing.Dict[str, str]``)
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['device_configuration', 'thing_name']
 
-    def __init__(self, device_configuration=None, thing_name=None):
-        # type: (typing.Optional[typing.Dict[str, str]], typing.Optional[str]) -> None
-        self.device_configuration = device_configuration # type: typing.Optional[typing.Dict[str, str]]
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a RegisterThingResponse instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *device_configuration* (``typing.Dict[str, str]``)
+            * *thing_name* (``str``)
+        """
+
+        self.device_configuration = kwargs.get('device_configuration')
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['device_configuration', 'thing_name'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -406,9 +575,28 @@ class RegisterThingResponse(awsiot.ModeledClass):
         return new
 
 class RegisterThingSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *template_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['template_name']
 
-    def __init__(self, template_name=None):
-        # type: (typing.Optional[str]) -> None
-        self.template_name = template_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a RegisterThingSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *template_name* (``str``)
+        """
+
+        self.template_name = kwargs.get('template_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['template_name'], args):
+            setattr(self, key, val)
 
